@@ -90,6 +90,7 @@ eel_mime_application_chooser_finalize (GObject *object)
 
 	g_free (chooser->details->uri);
 	g_free (chooser->details->mime_type);
+	g_free (chooser->details->real_mime_type);
 	g_free (chooser->details->mime_description);
 	
 	g_free (chooser->details);
@@ -278,7 +279,7 @@ static void
 remove_clicked_cb (GtkButton *button, 
 		   gpointer user_data)
 {
-	const char *id;
+	char *id;
 	EelMimeApplicationChooser *chooser;
 	
 	chooser = EEL_MIME_APPLICATION_CHOOSER (user_data);
@@ -288,6 +289,7 @@ remove_clicked_cb (GtkButton *button,
 	if (id) {
 		eel_mime_application_remove (id);
 		refresh_model (chooser);
+		g_free (id);
 	}
 }
 
